@@ -643,6 +643,13 @@ async fn test_django_mysql() {
     assert!(output.contains("Running migrations"));
 }
 
+#[tokio::test]
+async fn test_lunatic_basic() {
+    let name = simple_build("./examples/lunatic-basic").await;
+    let output = run_image(&name, None).await;
+    assert!(output.contains("PING-PONG"));
+}
+
 #[tokio::test]
 async fn test_python_poetry() {
     let name = simple_build("./examples/python-poetry").await;
@@ -726,6 +733,13 @@ async fn test_rust_multiple_bins() {
     assert!(output.contains("Bin 1"));
 }
 
+#[tokio::test]
+async fn test_gleam_basic() {
+    let name = simple_build("./examples/basic_gleam").await;
+    let output = run_image(&name, None).await;
+    assert!(output.contains("Hello from Gleam!"));
+}
+
 #[tokio::test]
 async fn test_go() {
     let name = simple_build("./examples/go").await;
